Type: Package
Package: hce
Title: Design and Analysis of Hierarchical Composite Endpoints
Version: 0.9.4
Authors@R: 
    person("Samvel B.", "Gasparyan", , "gasparyan.co@gmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-4797-2208"))
Description: Simulate and analyze hierarchical composite endpoints with univariate distributions by Gasparyan, Koch, Brunner in (2025) in “The Univariate Distribution of Hierarchical Composite Endpoints and the Condorcet Non-transitivity Paradox.” (Biometrical Journal 68 (3), <doi:10.1002/bimj.70140>). Includes implementation for the kidney hierarchical composite endpoint as defined in Heerspink HL et al (2023) “Development and validation of a new hierarchical composite end point for clinical trials of kidney disease progression” (Journal of the American Society of Nephrology 34 (2): 2025–2038, <doi:10.1681/ASN.0000000000000243>). Win odds, also called Wilcoxon-Mann-Whitney or success odds, is the main analysis method, but other win statistics (win probability, win ratio, net benefit) are also implemented in the univariate case. The win probability analysis is based on the Brunner-Munzel test and uses the DeLong-DeLong-Clarke-Pearson variance estimator, as described by Brunner and Konietschke (2025) in “An unbiased rank-based estimator of the Mann–Whitney variance including the case of ties” (Statistical Papers 66 (1): 20, <doi:10.1007/s00362-024-01635-0>). Includes implementation of a new Wilson-type, compatible confidence interval for the win odds, as proposed by Schüürhuis, Konietschke, Brunner (2025) in “A new approach to the nonparametric Behrens–Fisher problem with compatible confidence intervals.” (Biometrical Journal 67 (6), <doi:10.1002/bimj.70096>). Stratification and covariate adjustment are performed based on the methodology presented by Koch GG et al. in “Issues for covariance analysis of dichotomous and ordered categorical data from randomized clinical trials and non-parametric strategies for addressing them” (Statistics in Medicine 17 (15-16): 1863–92). For a review, see Gasparyan SB et al (2021) “Adjusted win ratio with stratification: Calculation methods and interpretation” (Statistical Methods in Medical Research 30 (2): 580–611, <doi:10.1177/0962280220942558>).
License: MIT + file LICENSE
BugReports: https://github.com/Samve/hce/issues
Depends: R (>= 3.5.0)
Imports: base, stats
Suggests: knitr, rmarkdown
Encoding: UTF-8
LazyData: true
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-06-26 18:08:20 UTC; r461986
Author: Samvel B. Gasparyan [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-4797-2208>)
Maintainer: Samvel B. Gasparyan <gasparyan.co@gmail.com>
Repository: CRAN
Date/Publication: 2026-06-26 19:00:02 UTC
Built: R 4.5.2; ; 2026-06-26 19:15:22 UTC; unix
