# Generated by roxygen2: do not edit by hand

S3method(as_formulae,formula)
S3method(as_hce,data.frame)
S3method(as_hce,default)
S3method(calcWINS,data.frame)
S3method(calcWINS,formula)
S3method(calcWINS,hce)
S3method(calcWO,data.frame)
S3method(calcWO,formula)
S3method(calcWO,hce)
S3method(deltaWO,adhce)
S3method(plot,hce)
S3method(plot,hce_results)
S3method(print,hce_results)
S3method(regWO,data.frame)
S3method(regWO,formula)
S3method(stratWO,data.frame)
S3method(stratWO,formula)
S3method(summaryWO,adhce)
S3method(summaryWO,data.frame)
S3method(summaryWO,formula)
S3method(summaryWO,hce)
export(HGLL)
export(IWP)
export(as_formulae)
export(as_hce)
export(calcWINS)
export(calcWO)
export(dGLL)
export(deltaWO)
export(hGLL)
export(hce)
export(minWO)
export(pGLL)
export(powerWO)
export(propWINS)
export(qGLL)
export(rGLL)
export(regWO)
export(rweibullGF)
export(simHCE)
export(simKHCE)
export(simORD)
export(simTTE)
export(sizeWO)
export(sizeWR)
export(stratWO)
export(summaryWO)
