# hce <img src="man/figures/logo.png" align="right" width="200" />

![Maturity level-Stable](https://img.shields.io/badge/Maturity%20Level-Stable-orange)
[![CRAN status](https://www.r-pkg.org/badges/version-last-release/hce)](https://CRAN.R-project.org/package=hce)
[![Downloads](https://cranlogs.r-pkg.org/badges/hce)](https://CRAN.R-project.org/package=hce)
[![All Downloads](https://cranlogs.r-pkg.org/badges/grand-total/hce)](https://CRAN.R-project.org/package=hce)

Simulate and analyze hierarchical composite endpoints

# Download

You can install hce from CRAN:

```
install.packages("hce")
```
